@@ -37,8 +37,8 @@ BEGIN {
   
 	$Data::Dumper::Sortkeys = 1;
 
-	$Eludia_VERSION      = $Eludia::VERSION      = '07.09.23';
-	$Eludia_VERSION_NAME = $Eludia::VERSION_NAME = 'Klin';
+	$Eludia_VERSION      = $Eludia::VERSION      = '07.10.02';
+	$Eludia_VERSION_NAME = $Eludia::VERSION_NAME = 'Halfmoreyear';
 
 	eval {
 		require Math::FixedPrecision;
@@ -123,6 +123,7 @@ BEGIN {
 		__last_query_string => 1,
 		__last_scrollable_table_row => 1,
 		__no_navigation => 1,
+		__tree => 1,
 		__infty => 1,
 		__no_infty => 1,
 	};
@@ -134,6 +135,8 @@ BEGIN {
 		password => 1,
 		error => 1,
 	};
+	
+	our $_JSON ||= JSON::XS -> new -> latin1 (1);
 		
 	unless ($ENV {ELUDIA_BANNER_PRINTED}) {
 
